/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.marmotta.commons.util;

import org.junit.Assert;
import org.junit.Test;

import java.util.Date;

/**
 * Unit-Tests for {@link DateUtils}.
 */
public class DateUtilsTest {

    @Test
    public void testParseIso8601Date() {
        // MARMOTTA-282
        Date now = new Date(System.currentTimeMillis());
        
        Assert.assertEquals(now, DateUtils.parseDate(DateUtils.ISO8601FORMAT.format(now)));
    }

    @Test
    public void testCalendarRoundTrip() {
        Date now = new Date(System.currentTimeMillis());
        Assert.assertEquals(now, DateUtils.getDate(DateUtils.getXMLCalendar(now)));
    }


    @Test
    public void testParseFreebaseDate() {
        String dateString = "1961-08-04T19:24";
        Date date = DateUtils.parseDate(dateString);

        Assert.assertNotNull(date);
        Assert.assertEquals(61, date.getYear());
    }
}
